@@ -36,15 +36,19 @@
 #include "src/annotations/misc/AnnotationContextMenu.h"
 #include "src/backend/Config.h"
 #include "src/common/enum/Tools.h"
+#include "src/common/enum/FlipDirection.h"
 #include "src/common/helper/CursorHelper.h"
 #include "src/common/helper/KeyHelper.h"
 #include "src/common/provider/IDevicePixelRatioScaler.h"
 #include "src/common/filter/KeyEventListener.h"
 #include "src/annotations/undo/UndoStack.h"
 #include "src/annotations/undo/CropCommand.h"
+#include "src/annotations/undo/FlipCommand.h"
 #include "src/annotations/undo/ScaleCommand.h"
 #include "src/annotations/undo/PasteCommand.h"
 #include "src/annotations/undo/ChangePropertiesCommand.h"
+#include "src/annotations/undo/ModifyCanvasCommand.h"
+#include "src/annotations/undo/RotateCommand.h"
 #include "src/annotations/core/ZoomValueProvider.h"
 #include "src/annotations/core/imageEffects/ImageEffectFactory.h"
 
@@ -65,12 +69,21 @@ public:
     virtual void removeAnnotationItem(AbstractAnnotationItem *item);
     virtual void crop(const QRectF& rect);
     virtual void scale(const QSize& size);
+    virtual void rotate(qreal angel);
+    virtual void flip(FlipDirection direction);
     virtual void clearSelection();
 	virtual void toolChanged(Tools toolType) override;
-	void itemSettingsChanged();
-	void firstBadgeNumberChanged(int number) override;
-	int firstBadgeNumber() const override;
+	void itemSettingsChanged() override;
+	void numberToolSeedChanged(int numberToolSeed) override;
+	int numberToolSeed() const override;
 	void imageEffectChanged(ImageEffects effect) override;
+	void setCanvasRect(const QRectF &rect);
+	QRectF canvasRect() const;
+	bool isCustomCanvasRect() const;
+	void setCanvasColor(const QColor &color);
+	QColor canvasColor() const;
+	void modifyCanvas(const QRectF &canvasRect, const QColor &color);
+	QRectF backgroundImageRect() const;
 
 public slots:
     virtual void update();
@@ -87,10 +100,11 @@ protected:
 	void contextMenuEvent(QGraphicsSceneContextMenuEvent * event) override;
 
 private:
+	Config *mConfig;
 	AbstractSettingsProvider *mSettingsProvider;
 	AnnotationPropertiesFactory *mPropertiesFactory;
 	AnnotationItemFactory *mItemFactory;
-    QSharedPointer<QGraphicsPixmapItem> mImage;
+    QSharedPointer<QGraphicsPixmapItem> mBackgroundImage;
     AbstractAnnotationItem *mCurrentItem;
     AnnotationItemModifier *mItemModifier;
     QList<AbstractAnnotationItem*> *mItems;
@@ -101,13 +115,16 @@ private:
 	QAction *mRedoAction;
 	IDevicePixelRatioScaler *mDevicePixelRatioScaler;
 	KeyEventListener mKeyListener;
-	Config *mConfig;
+	QRectF mCanvasRect;
+	QColor mCanvasColor;
 
     void addItemAtPosition(const QPointF& position);
     void addPointToCurrentItem(const QPointF& position);
 	void resetAnnotationArea();
 	void removeAllItems();
 	void replaceBackgroundImage(const QPixmap &image);
+	void finishDrawingItem(const QPointF &pos);
+	QRectF annotationItemsBoundingRect() const;
 
 private slots:
     void deleteSelectedItems();
